==> maxdb-all-linux-64bit-x86_64-7_6_00_36.tgz: SAPDB/Install/Control/Database.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V76/c_00/b_36/sys/src/install/perl/SAPDB/Install/Control/Database.pm#1 $
# $DateTime: 2006/11/17 17:24:42 $
# $Change: 140017 $
#
# Desc: 

package SAPDB::Install::Control::Database;

use Wx::Event qw (EVT_MENU);

use Wx qw ();

use base SAPDB::Install::Control::Item;
use SAPDB::Install::Menu::Database;
use SAPDB::Install::Resources;
use SAPDB::Install::DBMCmd;

sub new{
	my($self ) = shift->SUPER::new(@_);
	$self->SetBackgroundColour($self->GetParent->GetBackgroundColour);
	my $images = SAPDB::Install::Resources->new('RESOURCES.TGZ')->getImages('icon/db.png');
	return undef unless defined $images;
	$self->SetImage($images->{'icon/db.png'});
	return $self;
}

sub SetDBName{
	my ($self,$dbname) = @_;
	$self->SetLabel($dbname);
	return 1;	
}

sub ShowContextMenu{
	my ($self,$pos) = @_;
	EVT_MENU($self,1,\&OnConnect);
	EVT_MENU($self,2,\&OnDisconnect);
	EVT_MENU($self,3,\&OnOnline);
	EVT_MENU($self,4,\&OnAdmin);
	EVT_MENU($self,5,\&OnOffline);
	EVT_MENU($self,6,\&OnSendToDBMGui);
	$self->RefreshState();
	my $menu = SAPDB::Install::Menu::Database->new($self->{'label'},$self->{'state'});
	$self->PopupMenu($menu,$pos);
}

sub RefreshState{
	my ($self) = @_;
	$self->{'state'} = 'unkown';
	if (exists $self->{'dbm'}){
		$self->{'state'} = $self->{'dbm'}->db_state();
		$self->SetToolTip($self->{'label'}.'@'.
						($self->{'host'} =~ /\S/ ? $self->{'host'} : 
						'localhost').' is '.$self->{'state'});
	}
	else{
		delete $self->{'state'};
		$self->SetToolTip('Not connected');
	}
	$self->RenderState();	
	
}

sub OnConnect{
	my ($self,$evt) = @_;
	
	return if exists $self->{'dbm'} and defined $self->{'dbm'};
	
	my $bcursor = Wx::BusyCursor->new();
	$self->{'lastaction'} = 'CONNECT';
	delete $self->{'errstate'};
	
	
	if (exists $self->{'login_data'}){
	
		$self->{'dbm'} = SAPDB::Install::DBMCmd->new($self->{'host'},$self->{'label'}) unless (defined $self->{'dbm'});
	
		$self->{'dbm'} = SAPDB::Install::DBMCmd->new('localhost',$self->{'label'}) unless (defined $self->{'dbm'});
	
		unless (defined $self->{'dbm'}){
			$self->{'errstate'} = 1;	
			$self->{'lasterr'} = 'Cannot connect to database';
			return undef;
		}
	
		my $rc = $self->{'dbm'}->user_logon($self->{'login_data'});
		if (not defined $rc){
			$self->{'errstate'} = 1;	
			$self->{'lasterr'} = 'User logon failed: '.$self->{'dbm'}->lastmsg;
			return;
		}
	}
	else{
		require SAPDB::Install::Dialog::DBLogin;
		my $logindlg = SAPDB::Install::Dialog::DBLogin->new({'dbname' => $self->{'label'}},$self,-1);
		unless ($logindlg->ShowModal()){
			return undef;
		}
		$self->{'dbm'} = $logindlg->{'dbm'};
		$self->{'login_data'} = $logindlg->{'login_data'};
		$logindlg->Destroy;
		$logindlg = undef;	
	}
	$self->RefreshState;
	
}
 
sub OnDisconnect{
	my ($self,$evt) = @_;
	$self->{'dbm'}->release;
	delete $self->{'dbm'};
	$self->RefreshState();
} 

sub OnOnline{
	my ($self,$evt) = @_;
	my $bcursor = Wx::BusyCursor->new();
	$self->{'lastaction'} = 'ONLINE';
	delete $self->{'errstate'};
	my $rc = $self->{'dbm'}->db_online;
	unless (defined $rc){
		$self->{'errstate'} = 1;	
		$self->{'lasterr'} = 'Cannot switch to state ONLINE: '.$self->{'dbm'}->lastmsg;
	}
	$self->RefreshState();
	return 1;
} 

sub OnSendToDBMGui{
	my ($self,$evt) = @_;
	my $bcursor = Wx::BusyCursor->new();
	my $dbmgui = SAPDB::Install::Registry::GetDBMGui();
	my $home_dir = $ENV{'HOMEDRIVE'}.$ENV{'HOMEPATH'};
	my $cwd;
	if($dbmgui =~ /\S/ and -f $dbmgui){
		my $user_password;
		my $options = "-d ".$self->{'label'}." -u ".$self->{'login_data'};
		if(-d $home_dir){
			require SAPDB::Install::Cwd;
			$cwd = SAPDB::Install::Cwd::getcwd();	
			chdir($home_dir);
		}
		system('rundll32.exe shell32.dll,ShellExec_RunDLLA "'.$dbmgui.'" '.$options);			
		if($cwd =~ /\S/){
			chdir($cwd);
		}
	}
	return 1;
} 

sub OnSendToSQLStudio{
	my ($self,$evt) = @_;
	my $bcursor = Wx::BusyCursor->new();
	my $sqlstudio = SAPDB::Install::Registry::GetSQLStudio();
	my $home_dir = $ENV{'HOMEDRIVE'}.$ENV{'HOMEPATH'};
	my $cwd;
	if($sqlstudio =~ /\S/ and -f $sqlstudio){
		my $user_password;
		my $options = "-d ".$self->{'label'}." -u ".$self->{'login_data'};
		if(-d $home_dir){
			require SAPDB::Install::Cwd;
			$cwd = SAPDB::Install::Cwd::getcwd();	
			chdir($home_dir);
		}
		system('rundll32.exe shell32.dll,ShellExec_RunDLLA "'.$sqlstudio.'" '.$options);			
		if($cwd =~ /\S/){
			chdir($cwd);
		}
	}
	return 1;
}


sub OnAdmin{
	my ($self,$evt) = @_;
	my $bcursor = Wx::BusyCursor->new();
	$self->{'lastaction'} = 'ADMIN';
	delete $self->{'errstate'};
	my $rc = $self->{'dbm'}->db_admin;
	unless (defined $rc){
		$self->{'errstate'} = 1;	
		$self->{'lasterr'} = 'Cannot switch to state ADMIN: '.$self->{'dbm'}->lastmsg;
	}
	$self->RefreshState();
}

sub OnOffline{
	my ($self,$evt) = @_;
	my $bcursor = Wx::BusyCursor->new();
	$self->{'dbm'}->db_offline;
	$self->RefreshState();
}


sub RenderState{
	my ($self) = @_;
	my $image_name = 'icon/db.png';
	if (exists $self->{'state'}){
		if ($self->{'state'} =~ /online|warm/i){
			$image_name = 'icon/dbonline.png';
		}
		elsif ($self->{'state'} =~ /admin|cold/i){
			$image_name = 'icon/dbadmin.png';
		}
		elsif ($self->{'state'} =~ /offline/i){
			$image_name = 'icon/dboffline.png';
		}
	}
	
	if (exists $self->{'image_name'} and 
		$image_name eq $self->{'image_name'}){
		return 1;
	}
	
	$self->{'image_name'} = $image_name;
	 
	my $images = SAPDB::Install::Resources->new('RESOURCES.TGZ')->getImages($image_name);
	return unless exists $images->{$image_name};
	$self->SetImage($images->{$image_name});
	return 1;
	
}


sub Destroy{
	my ($self) = @_;
	$self->SUPER::Destroy;
}

sub DESTROY{
	my ($self) = @_;
	if (exists $self->{'dbm'}){
		$self->{'dbm'}->release;
		delete $self->{'dbm'};
	}
	print ">>>> DESTROY $self\n"
		if $SAPDB::Install::DEBUG::DESTRUCT;
}


sub AUTOLOAD{
	my $self = shift;
	my $name = $AUTOLOAD;
	my $type = ref($self);
	
	$name =~ s/.*://;
	
	return undef unless(exists $self->{'dbm'});
	
	return undef if $name =~ /destroy/i;
	
	if ($self->{'dbm'}->can($name)){
		return $self->{'dbm'}->$name(@_); 
	}
	else{
		return undef;
	}
}

1;

==> maxdb-all-linux-64bit-x86_64-7_6_03_15.tgz: SAPDB/Install/Control/Database.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V76/c_03/b_15/sys/src/install/perl/SAPDB/Install/Control/Database.pm#1 $
# $DateTime: 2008/01/18 16:05:39 $
# $Change: 173096 $
#
# Desc: 

package SAPDB::Install::Control::Database;

use Wx::Event qw (EVT_MENU);

use Wx qw (wxICON_ERROR wxCENTRE);

use base SAPDB::Install::Control::Item;
use SAPDB::Install::Menu::Database;
use SAPDB::Install::Resources;
use SAPDB::Install::DBMCmd;

sub new{
	my($self ) = shift->SUPER::new(@_);
	$self->SetBackgroundColour($self->GetParent->GetBackgroundColour);
	my $images = SAPDB::Install::Resources->new('RESOURCES.TGZ')->getImages('icon/db.png');
	return undef unless defined $images;
	$self->SetImage($images->{'icon/db.png'});
	return $self;
}

sub SetDBName{
	my ($self,$dbname) = @_;
	$self->SetLabel($dbname);
	return 1;	
}

sub DoAsynchronousCmd{
	my ($self,$cmd) = @_;
	delete $self->{'errstate'};
	my $sess_id = $self->{'dbm'}->send ($cmd);
	my $id;
	while (1){
		$id = $self->{'dbm'}->select (1);
		if ($sess_id == $id || $id == -1){
			last;
		}
		&$SAPDB::Install::Values::RefreshGui();		
	}
	
	if ($id == -1){
		$self->{'errstate'} = 1;	
		$self->{'lasterr'} = 'Cannot switch to state '.
							  $self->{'lastaction'}.
							  ': error in asynchronous dbm communication: select() failed';
		$self->ShowErrorDialog();
	}
	else{
		my ($rc) = split ('\n', $self->{'dbm'}->recv ($sess_id));
	
		unless ($rc =~ /^OK/){
			$self->{'errstate'} = 1;	
			$self->{'lasterr'} = 'Cannot switch to state '.$self->{'lastaction'}.
									': '.$self->{'dbm'}->lastmsg;
			$self->ShowErrorDialog();
		}
	}		
	return 1;
}

sub ShowContextMenu{
	my ($self,$pos) = @_;
	EVT_MENU($self,1,\&OnConnect);
	EVT_MENU($self,2,\&OnDisconnect);
	EVT_MENU($self,3,\&OnOnline);
	EVT_MENU($self,4,\&OnAdmin);
	EVT_MENU($self,5,\&OnOffline);
	EVT_MENU($self,6,\&OnSendToDBMGui);
	EVT_MENU($self,7,\&OnSendToSQLStudio);
	$self->RefreshState();
	my $menu = SAPDB::Install::Menu::Database->new($self->{'label'},$self->{'state'});
	$self->PopupMenu($menu,$pos);
}

sub RefreshState{
	my ($self) = @_;
	$self->{'state'} = 'unkown';
	if (exists $self->{'dbm'}){
		$self->{'state'} = $self->{'dbm'}->db_state();
		$self->SetToolTip($self->{'label'}.'@'.
						($self->{'host'} =~ /\S/ ? $self->{'host'} : 
						'<localhost>').' is '.$self->{'state'});
	}
	else{
		delete $self->{'state'};
		$self->SetToolTip('Not connected');
	}
	$self->RenderState();	
	
}

sub ShowErrorDialog{
	my ($self) = @_;
	return unless $self->{'errstate'};
	my $host = defined $self->{'host'} ? $self->{'host'} : '<localhost>'; 
	my $dlg = Wx::MessageDialog->new ($self,$self->{'lasterr'},'Error '.
										$self->{'label'}.'@'.$host, wxICON_ERROR | wxCENTRE);
	$dlg->ShowModal ();
	$dlg->Destroy ();
	return 1;
}


sub OnConnect{
	my ($self,$evt) = @_;
	
	return if exists $self->{'dbm'} and defined $self->{'dbm'};
	
	my $bcursor = Wx::BusyCursor->new();
	$self->{'lastaction'} = 'CONNECT';
	delete $self->{'errstate'};
	
	
	if (exists $self->{'login_data'}){
	
		$self->{'dbm'} = SAPDB::Install::DBMCmd->new($self->{'host'},$self->{'label'}) unless (defined $self->{'dbm'});
	
		$self->{'dbm'} = SAPDB::Install::DBMCmd->new('localhost',$self->{'label'}) unless (defined $self->{'dbm'});
	
		unless (defined $self->{'dbm'}){
			$self->{'errstate'} = 1;	
			$self->{'lasterr'} = 'cannot get DBM object';
			$self->ShowErrorDialog();
			return undef;
		}
		
		if (defined $self->{'dbm'}->lasterr ()){
			$self->{'errstate'} = 1;	
			$self->{'lasterr'} = 'Cannot connect to database: '.$self->{'dbm'}->lasterr ();
			$self->ShowErrorDialog();
			return undef;
		}
		
	
		my $rc = $self->{'dbm'}->user_logon($self->{'login_data'});
		if (not defined $rc){
			$self->{'errstate'} = 1;	
			$self->{'lasterr'} = 'User logon failed: '.$self->{'dbm'}->lastmsg;
			return;
		}
	}
	else{
		require SAPDB::Install::Dialog::DBLogin;
		my $logindlg = SAPDB::Install::Dialog::DBLogin->new({'dbname' => $self->{'label'}},$self,-1);
		unless ($logindlg->ShowModal()){
			$logindlg->Destroy;
			return undef;
		}
		$self->{'dbm'} = $logindlg->{'dbm'};
		$self->{'login_data'} = $logindlg->{'login_data'};
		$logindlg->Destroy;
		$logindlg = undef;	
	}
	$self->RefreshState;
	
}
 
sub OnDisconnect{
	my ($self,$evt) = @_;
	$self->{'dbm'}->release;
	delete $self->{'dbm'};
	$self->RefreshState();
} 

sub OnOnline{
	my ($self,$evt) = @_;
	my $bcursor = Wx::BusyCursor->new();
	$self->Enable (0);
	$self->{'lastaction'} = 'ONLINE';
	$self->DoAsynchronousCmd ('db_online');
	$self->Enable (1);
	$self->RefreshState();
	return 1;
} 

sub OnSendToDBMGui{
	my ($self,$evt) = @_;
	my $bcursor = Wx::BusyCursor->new();
	my $dbmgui = SAPDB::Install::Registry::GetDBMGui();
	my $home_dir = $ENV{'HOMEDRIVE'}.$ENV{'HOMEPATH'};
	my $cwd;
	if($dbmgui =~ /\S/ and -f $dbmgui){
		my $user_password;
		my $options = "-d ".$self->{'label'}." -u ".$self->{'login_data'};
		if(-d $home_dir){
			require SAPDB::Install::Cwd;
			$cwd = SAPDB::Install::Cwd::getcwd();	
			chdir($home_dir);
		}
		system('rundll32.exe shell32.dll,ShellExec_RunDLLA "'.$dbmgui.'" '.$options);			
		if($cwd =~ /\S/){
			chdir($cwd);
		}
	}
	return 1;
} 

sub OnSendToSQLStudio{
	my ($self,$evt) = @_;
	my $bcursor = Wx::BusyCursor->new();
	my $sqlstudio = SAPDB::Install::Registry::GetSQLStudio();
	my $home_dir = $ENV{'HOMEDRIVE'}.$ENV{'HOMEPATH'};
	my $cwd;
	if($sqlstudio =~ /\S/ and -f $sqlstudio){
		my $user_password;
		my $options = "-d ".$self->{'label'}." -u ".$self->{'login_data'};
		if(-d $home_dir){
			require SAPDB::Install::Cwd;
			$cwd = SAPDB::Install::Cwd::getcwd();	
			chdir($home_dir);
		}
		system('rundll32.exe shell32.dll,ShellExec_RunDLLA "'.$sqlstudio.'" '.$options);			
		if($cwd =~ /\S/){
			chdir($cwd);
		}
	}
	return 1;
}


sub OnAdmin{
	my ($self,$evt) = @_;
	my $bcursor = Wx::BusyCursor->new();
	$self->Enable (0);
	$self->{'lastaction'} = 'ADMIN';
	$self->DoAsynchronousCmd ('db_admin');
	$self->Enable (1);
	$self->RefreshState();
}

sub OnOffline{
	my ($self,$evt) = @_;
	my $bcursor = Wx::BusyCursor->new();
	$self->Enable (0);
	$self->{'lastaction'} = 'OFFLINE';
	$self->DoAsynchronousCmd ('db_offline');
	$self->Enable (1);
	$self->RefreshState();
}


sub RenderState{
	my ($self) = @_;
	my $image_name = 'icon/db.png';
	if (exists $self->{'state'}){
		if ($self->{'state'} =~ /online|warm/i){
			$image_name = 'icon/dbonline.png';
		}
		elsif ($self->{'state'} =~ /admin|cold/i){
			$image_name = 'icon/dbadmin.png';
		}
		elsif ($self->{'state'} =~ /offline/i){
			$image_name = 'icon/dboffline.png';
		}
	}
	
	if (exists $self->{'image_name'} and 
		$image_name eq $self->{'image_name'}){
		return 1;
	}
	
	$self->{'image_name'} = $image_name;
	 
	my $images = SAPDB::Install::Resources->new('RESOURCES.TGZ')->getImages($image_name);
	return unless exists $images->{$image_name};
	$self->SetImage($images->{$image_name});
	return 1;
	
}


sub Destroy{
	my ($self) = @_;
	$self->SUPER::Destroy;
}

sub DESTROY{
	my ($self) = @_;
	if (exists $self->{'dbm'}){
		$self->{'dbm'}->release;
		delete $self->{'dbm'};
	}
	print ">>>> DESTROY $self\n"
		if $SAPDB::Install::DEBUG::DESTRUCT;
}


sub AUTOLOAD{
	my $self = shift;
	my $name = $AUTOLOAD;
	my $type = ref($self);
	
	$name =~ s/.*://;
	
	return undef unless(exists $self->{'dbm'});
	
	return undef if $name =~ /destroy/i;
	
	if ($self->{'dbm'}->can($name)){
		return $self->{'dbm'}->$name(@_); 
	}
	else{
		return undef;
	}
}

1;
